==> qbittorrent_3.3.1.orig.tar.xz: qbittorrent-3.3.1/src/base/http/connection.h <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2014  Vladimir Golovnev <glassez@yandex.ru>
 * Copyright (C) 2006  Ishan Arora and Christophe Dumez
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 *
 * Contact : chris@qbittorrent.org
 */


#ifndef HTTP_CONNECTION_H
#define HTTP_CONNECTION_H

#include <QObject>
#include "types.h"

QT_BEGIN_NAMESPACE
class QTcpSocket;
QT_END_NAMESPACE

namespace Http
{
    class IRequestHandler;

    class Connection : public QObject
    {
        Q_OBJECT
        Q_DISABLE_COPY(Connection)

    public:
        Connection(QTcpSocket *socket, IRequestHandler *requestHandler, QObject *parent = 0);
        ~Connection();

    private slots:
        void read();

    private:
        static bool acceptsGzipEncoding(const QString &encoding);
        void sendResponse(const Response &response);

        QTcpSocket *m_socket;
        IRequestHandler *m_requestHandler;
        QByteArray m_receivedData;
    };
}

#endif // HTTP_CONNECTION_H

==> qbittorrent_4.0.3.orig.tar.xz: qbittorrent-4.0.3/src/base/http/connection.h <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2014  Vladimir Golovnev <glassez@yandex.ru>
 * Copyright (C) 2006  Ishan Arora and Christophe Dumez
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 *
 * Contact : chris@qbittorrent.org
 */


#ifndef HTTP_CONNECTION_H
#define HTTP_CONNECTION_H

#include <QElapsedTimer>
#include <QObject>

#include "types.h"

class QTcpSocket;

namespace Http
{
    class IRequestHandler;

    class Connection : public QObject
    {
        Q_OBJECT
        Q_DISABLE_COPY(Connection)

    public:
        Connection(QTcpSocket *socket, IRequestHandler *requestHandler, QObject *parent = 0);
        ~Connection();

        bool hasExpired(qint64 timeout) const;
        bool isClosed() const;

    private slots:
        void read();

    private:
        static bool acceptsGzipEncoding(QString codings);
        void sendResponse(const Response &response);

        QTcpSocket *m_socket;
        IRequestHandler *m_requestHandler;
        QByteArray m_receivedData;
        QElapsedTimer m_idleTimer;
    };
}

#endif // HTTP_CONNECTION_H
